Description Usage Arguments Details Value
dir_name() get directory name of url or path. It works similar to but a little different from dirname().
1 |
path |
character. |
It doesn't works on single file name, i.e. dir_name('foo/bar') is okay but dir_name('foobar') doesn't return what you want. Since it is used to transform relative url to absolute url, dir_name('www.github.com') must return 'www.github.com'.
character. with tailing '/'
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.